==> qpid-jms-client-0.7.0-sources.jar: org/apache/qpid/jms/sasl/ExternalMechanism.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.sasl;

import java.security.Principal;

/**
 * Implements the External SASL authentication mechanism.
 */
public class ExternalMechanism extends AbstractMechanism {

    @Override
    public byte[] getInitialResponse() {
        return EMPTY;
    }

    @Override
    public byte[] getChallengeResponse(byte[] challenge) {
        return EMPTY;
    }

    @Override
    public int getPriority() {
        return PRIORITY.HIGHER.getValue();
    }

    @Override
    public String getName() {
        return "EXTERNAL";
    }

    @Override
    public boolean isApplicable(String username, String password, Principal localPrincipal) {
        return localPrincipal != null;
    }
}

==> qpid-jms-client-0.42.0-sources.jar: org/apache/qpid/jms/sasl/ExternalMechanism.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.qpid.jms.sasl;

import java.security.Principal;

/**
 * Implements the External SASL authentication mechanism.
 */
public class ExternalMechanism extends AbstractMechanism {

    @Override
    public byte[] getInitialResponse() {
        return EMPTY;
    }

    @Override
    public byte[] getChallengeResponse(byte[] challenge) {
        return EMPTY;
    }

    @Override
    public int getPriority() {
        return PRIORITY.HIGHER_STILL.getValue();
    }

    @Override
    public String getName() {
        return "EXTERNAL";
    }

    @Override
    public boolean isApplicable(String username, String password, Principal localPrincipal) {
        return localPrincipal != null;
    }
}
